package data

import (
	mongo "cloud.o-forge.io/core/oc-lib/dbs/mongo"
	"cloud.o-forge.io/core/oc-lib/models/utils"
)

type DataMongoAccessor struct {
	utils.AbstractAccessor
}

func (dma *DataMongoAccessor) DeleteOne(id string) (utils.DBObject, error) {
	return dma.GenericDeleteOne(id, dma)
}

func (dma *DataMongoAccessor) UpdateOne(set map[string]interface{}, id string) (utils.DBObject, error) {
	return dma.GenericUpdateOne(set, id, dma)
}

func (dma *DataMongoAccessor) StoreOne(data utils.DBObject) (utils.DBObject, error) {
	err := dma.Validate(data.(*Data))
	if err != nil {
		return nil, err
	}
	id, err := mongo.MONGOService.StoreOne(data.(*Data), dma.GetType())
	if err != nil {
		dma.Logger.Error().Msg("Could not store " + data.GetName() + " to db. Error: " + err.Error())
		return nil, err
	}
	return dma.LoadOne(id)
}

func (dma *DataMongoAccessor) LoadOne(id string) (utils.DBObject, error) {
	var data Data
	res_mongo, err := mongo.MONGOService.LoadOne(id, dma.GetType())
	if err != nil {
		dma.Logger.Error().Msg("Could not retrieve " + id + " from db. Error: " + err.Error())
		return nil, err
	}
	res_mongo.Decode(&data)

	return &data, nil
}
