package datacenter

import (
	"cloud.o-forge.io/core/oc-lib/dbs/mongo"
	"cloud.o-forge.io/core/oc-lib/models/utils"
)

type DatacenterMongoAccessor struct {
	utils.AbstractAccessor
}

func (dca *DatacenterMongoAccessor) DeleteOne(id string) (utils.DBObject, error) {
	return dca.GenericDeleteOne(id, dca)
}

func (dca *DatacenterMongoAccessor) UpdateOne(set map[string]interface{}, id string) (utils.DBObject, error) {
	return dca.GenericUpdateOne(set, id, dca)
}

func (dca *DatacenterMongoAccessor) StoreOne(data utils.DBObject) (utils.DBObject, error) {
	err := dca.Validate(data.(*Datacenter))
	if err != nil {
		return nil, err
	}
	id, err := mongo.MONGOService.StoreOne(data.(*Datacenter), dca.GetType())
	if err != nil {
		dca.Logger.Error().Msg("Could not store " + data.GetName() + " to db. Error: " + err.Error())
		return nil, err
	}
	return dca.LoadOne(id)
}

func (dca *DatacenterMongoAccessor) LoadOne(id string) (utils.DBObject, error) {
	var datacenter Datacenter

	res_mongo, err := mongo.MONGOService.LoadOne(id, dca.GetType())
	if err != nil {
		dca.Logger.Error().Msg("Could not retrieve " + id + " from db. Error: " + err.Error())
		return nil, err
	}

	res_mongo.Decode(&datacenter)

	return &datacenter, nil
}
