package oclib

import (
	"cloud.o-forge.io/core/oc-lib/dbs/mongo"
	"cloud.o-forge.io/core/oc-lib/models/utils"
)

type WorkflowMongoAccessor struct {
	utils.AbstractAccessor
}

func (wfa *WorkflowMongoAccessor) DeleteOne(id string) (utils.DBObject, error) {
	return wfa.GenericDeleteOne(id, wfa)
}

func (wfa *WorkflowMongoAccessor) UpdateOne(set map[string]interface{}, id string) (utils.DBObject, error) {
	return wfa.GenericUpdateOne(set, id, wfa)
}

func (wfa *WorkflowMongoAccessor) StoreOne(data utils.DBObject) (utils.DBObject, error) {
	err := wfa.Validate(data.(*Workflow))
	if err != nil {
		return nil, err
	}
	id, err := mongo.MONGOService.StoreOne(data.(*Workflow), wfa.GetType())
	if err != nil {
		wfa.Logger.Error().Msg("Could not store " + data.GetName() + " to db. Error: " + err.Error())
		return nil, err
	}
	return wfa.LoadOne(id)
}

func (wfa *WorkflowMongoAccessor) LoadOne(id string) (utils.DBObject, error) {
	var workflow Workflow
	res_mongo, err := mongo.MONGOService.LoadOne(id, wfa.GetType())
	if err != nil {
		wfa.Logger.Error().Msg("Could not retrieve " + id + " from db. Error: " + err.Error())
		return nil, err
	}
	res_mongo.Decode(&workflow)
	return &workflow, nil
}
